@@ -8,16 +8,15 @@ https://gnu.org/licenses/gpl-3.0.en.html
 '''
 
 from rich import traceback
-from pynput import keyboard
-from easyselect import Selection
+from pathlib import Path
+from easyselect import Sel
+from dataclasses import dataclass
 import shutil as sh
 import subprocess
 import rich
 import yaml
 import sys
 import os
-from pathlib import Path
-from dataclasses import dataclass
 
 rich.pretty.install()
 traceback.install(show_locals=True)
@@ -27,7 +26,6 @@ from prettygit.setup import version, yes_or_no
 c = rich.console.Console()
 print = c.print
 print(f'[bold][deep_sky_blue1]prettygit v[white]{version}')
-Key = keyboard.Key
 proj_path = os.getcwd()
 config_path = Path(f'{proj_path}/.git/prettygit.yml')
 run_st = subprocess.getstatusoutput
@@ -104,6 +102,10 @@ def create_config():
         )
         Data.git_path = Data.config['git_path']
     else:
+        config_path.parent.mkdir(
+            parents=True,
+            exist_ok=True,
+        )
         Data.config['branches'] = [
             'main',
             'beta',
@@ -169,10 +171,6 @@ def git_init():
         sys.exit()
     check_gitignore()
     run(f'{Data.git_path} init')
-    config_path.parent.mkdir(
-        parents=True,
-        exist_ok=True,
-    )
     check_username()
     check_email()
     if run(
@@ -238,7 +236,7 @@ def check_git():
             return
         else:
             if not selection:
-                selection = Selection(
+                selection = Sel(
                     items = [
                         'try again',
                         'input path',
@@ -312,7 +310,7 @@ After creating repo input link here:\
             url = 'https://' + url
 
         print(
-            f'use url [deep_sky_blue1]{url}[/deep_sky_blue1] for git?'
+            f'\nuse url [deep_sky_blue1]{url}[/deep_sky_blue1] for git?'
         )
 
         if yes_or_no.choose() == 'yes':
@@ -366,7 +364,7 @@ def delete_branch():
         ] + [
             'cancel'
         ]
-        branches = Selection(
+        branches = Sel(
             branches_list
         )
         branches.styles[-1] = 'green'
@@ -397,7 +395,7 @@ def select_branch():
             'delete branch',
             'cancel',
         ]
-        branches = Selection(
+        branches = Sel(
             branches_list
         )
         branches.styles[-3:] = (
@@ -531,11 +529,11 @@ def pypi():
         f'{proj_path}/pyproject.toml'
     ).exists():
         return
-    print('[green]do you want to upload package to pypi?')
+    print('\n[green]do you want to upload package to pypi?')
     if yes_or_no.choose() == 'no':
         return
     dist_path = Path(f'{proj_path}/dist')
-    print(f'[red]remove [deep_sky_blue1]{dist_path}[/deep_sky_blue1]?')
+    print(f'[red]remove [deep_sky_blue1]{dist_path}[/deep_sky_blue1] ?')
     if yes_or_no.choose() == 'no':
         return
     sh.rmtree(
